==> dkim-milter-1.0.0.tar.gz: dkim-milter-1.0.0/libdkim/t-testdata.h <==
/*
**  Copyright (c) 2007 Sendmail, Inc. and its suppliers.
**    All rights reserved.
*/

#ifndef lint
static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.7 2007/05/12 14:41:54 msk Exp $";
#endif /* !lint */

#define	HEADER01	"Received: received data 0"
#define	HEADER02	"Received: received data 1"
#define	HEADER03	"Received: received data 2"
#define	HEADER04	"Received: received data 3 part 1\r\n\t data 3 part 2"
#define	HEADER04UNWRAP	"Received: received data 3 part 1 data 3 part 2"
#define	HEADER05	"From: Murray S. Kucherawy <msk@sendmail.com>"
#define	HEADER06	"To: Sendmail Test Address <sa-test@sendmail.net>"
#define	HEADER07	"Date: Thu, 05 May 2005 11:59:09 -0700"
#define	HEADER07XLEADSP	"Date:   Thu, 05 May 2005 11:59:09 -0700"
#define	HEADER07NOLEADSP "Date:Thu, 05 May 2005 11:59:09 -0700"
#define	HEADER08	"Subject: DKIM test message"
#define	HEADER09	"Message-ID: <439094BF.5010709@sendmail.com>"

#define	BODY00		"This is a message body.  Fun!\r\n"
#define	BODY01		"Here is a second line.\r\n"
#define	BODY01A		"Here is a line"
#define	BODY01B		" that is broken up across calls.\r"
#define	BODY01C		"\n"
#define	BODY01D		"Now we can try something interesting, like a\r\nmulti-line buffer.  This should not be mangled.\r\n"
#define	BODY01E		"And a line with a trailing space: \r\n"
#define	BODY02		"Next we'll try a blank.\r\n"
#define	BODY03		"\r\n"
#define	BODY04		"Next we'll try multiple blanks.\r\n"
#define	BODY05		"Finally we'll try multiple trailing blanks.\r\n"
#define	BODY06		"Surprise, more data!\r\n"

#define THEADER00	"Received: from client1.football.example.com  [192.0.2.1]\r\n" \
	"      by submitserver.example.com with SUBMISSION;\r\n" \
	"      Fri, 11 Jul 2003 21:01:54 -0700 (PDT)"
#define	THEADER01	"From: Joe SixPack <joe@football.example.com>"
#define THEADER02	"To: Suzie Q <suzie@shopping.example.net>"
#define THEADER03	"Subject: Is dinner ready?"
#define THEADER04	"Date: Fri, 11 Jul 2003 21:00:37 -0700 (PDT)"
#define	THEADER05	"Message-ID: <20030712040037.46341.5F8J@football.example.com>"
#define	TBODY		"Hi.\r\n" \
			"\r\n" \
			"We lost the game. Are you hungry yet?\r\n" \
			"\r\n" \
			"Joe.\r\n"

#define KEY		"-----BEGIN RSA PRIVATE KEY-----\n" \
	"MIICXQIBAAKBgQC4GUGr+d/6SFNzVLYpphnRd0QPGKz2uWnV65RAxa1Pw352Bqiz\n" \
	"qiKOBjgYGzj8pJQSs8tOvv/2k6jpI809RnESqOFgF0gu3UJbNnu3+cd8k/kiQj+q\n" \
	"4cKKRpAT92ccxc7svhCNgN1sBGmROYZuysG3Vu3Dyc079gSLtnSrgXb+gQIDAQAB\n" \
	"AoGAemlI0opm1Kvs2T4VliH8/tvX5FXbBH8LEZQAUwVeFTB/UQlieXyCV39pIxZO\n" \
	"0Sa50qm8YNL9rb5HTSZiHQFOwyAKNqS4m/7JCsbuH4gQkPgPF561BHNL9oKfYgJq\n" \
	"9P4kEFfDTBoXKBMxwWtT7AKV8dYvCa3vYzPQ/1BnqQdw2zECQQDyscdgR9Ih59PQ\n" \
	"b72ddibdsxS65uXS2vzYLe7SKl+4R5JgJzw0M6DTAnoYFf6JAsKGZM15PCC0E16t\n" \
	"RRo47U9VAkEAwjEVrlQ0/8yPACbDggDJg/Zz/uRu1wK0zjqj4vKjleubaX4SEvj7\n" \
	"r6xxZm9hC1pMJAC9y3bbkbgCRBjXfyY6fQJBANe5aq2MaZ41wTOPf45NjbKXEiAo\n" \
	"SbUpboKCIbyyaa8V/2h0t7D3C0dE9l4efsguqdZoF7Rh2/f1F70QpYRgfJkCQQCH\n" \
	"oRrAeGXP50JVW72fNgeJGH/pnghgOa6of0JpxwhENJuGMZxUDfxTtUA6yD3iXP3j\n" \
	"A3WL/wbaHsfOYf9Y+g1NAkAGLhx67Ah+uBNK4Xvfz0YPGINX20m+CMsxAw7FOaNv\n" \
	"IW2oWFfZCB4APkIis79Ql45AHpavwx5XodBMzZwJUvlL\n" \
	"-----END RSA PRIVATE KEY-----\n"
#define	PUBLICKEY	"v=DKIM1; k=rsa; t=y; p=" \
	"MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC4GUGr+d/6SFNzVLYpphnRd0QP" \
	"GKz2uWnV65RAxa1Pw352BqizqiKOBjgYGzj8pJQSs8tOvv/2k6jpI809RnESqOFg" \
	"F0gu3UJbNnu3+cd8k/kiQj+q4cKKRpAT92ccxc7svhCNgN1sBGmROYZuysG3Vu3D" \
	"yc079gSLtnSrgXb+gQIDAQAB"
#define	PUBLICKEY2	"v=DKIM1; p=MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQ" \
	"KBgQDwIRP/UC3SBsEmGqZ9ZJW3/DkMoGeLnQg1fWn7/zYt" \
	"IxN2SnFCjxOCKG9v3b4jYfcTNh5ijSsq631uBItLa7od+v" \
	"/RtdC2UzJ1lWT947qR+Rcac2gbto/NMqJ0fzfVjH4OuKhi" \
	"tdY9tf6mcwGjaNBcWToIMmPSPDdQPNUYckcQ2QIDAQAB"

#define	KEYFILE		"/var/tmp/testkeys"

#define	JOBID		"testing"
#define	SELECTOR	"test"
#define	SELECTOR2	"brisbane"
#define	DOMAIN		"example.com"

==> dkim-milter_1.2.0.dfsg.orig.tar.gz: dkim-milter-1.2.0.dfsg/libdkim/t-testdata.h <==
/*
**  Copyright (c) 2007 Sendmail, Inc. and its suppliers.
**    All rights reserved.
*/

#ifndef lint
static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.8 2007/05/24 18:33:19 msk Exp $";
#endif /* !lint */

#define	HEADER01	"Received: received data 0"
#define	HEADER02	"Received: received data 1"
#define	HEADER03	"Received: received data 2"
#define	HEADER04	"Received: received data 3 part 1\r\n\t data 3 part 2"
#define	HEADER04UNWRAP	"Received: received data 3 part 1 data 3 part 2"
#define	HEADER05	"From: Murray S. Kucherawy <msk@sendmail.com>"
#define	HEADER06	"To: Sendmail Test Address <sa-test@sendmail.net>"
#define	HEADER07	"Date: Thu, 05 May 2005 11:59:09 -0700"
#define	HEADER07XLEADSP	"Date:   Thu, 05 May 2005 11:59:09 -0700"
#define	HEADER07NOLEADSP "Date:Thu, 05 May 2005 11:59:09 -0700"
#define	HEADER08	"Subject: DKIM test message"
#define	HEADER09	"Message-ID: <439094BF.5010709@sendmail.com>"

#define	BODY00		"This is a message body.  Fun!\r\n"
#define	BODY01		"Here is a second line.\r\n"
#define	BODY01A		"Here is a line"
#define	BODY01B		" that is broken up across calls.\r"
#define	BODY01C		"\n"
#define	BODY01D		"Now we can try something interesting, like a\r\nmulti-line buffer.  This should not be mangled.\r\n"
#define	BODY01E		"And a line with a trailing space: \r\n"
#define	BODY02		"Next we'll try a blank.\r\n"
#define	BODY03		"\r\n"
#define	BODY04		"Next we'll try multiple blanks.\r\n"
#define	BODY05		"Finally we'll try multiple trailing blanks.\r\n"
#define	BODY06		"Surprise, more data!\r\n"

#define THEADER00	"Received: from client1.football.example.com  [192.0.2.1]\r\n" \
	"      by submitserver.example.com with SUBMISSION;\r\n" \
	"      Fri, 11 Jul 2003 21:01:54 -0700 (PDT)"
#define	THEADER01	"From: Joe SixPack <joe@football.example.com>"
#define THEADER02	"To: Suzie Q <suzie@shopping.example.net>"
#define THEADER03	"Subject: Is dinner ready?"
#define THEADER04	"Date: Fri, 11 Jul 2003 21:00:37 -0700 (PDT)"
#define	THEADER05	"Message-ID: <20030712040037.46341.5F8J@football.example.com>"
#define	TBODY		"Hi.\r\n" \
			"\r\n" \
			"We lost the game. Are you hungry yet?\r\n" \
			"\r\n" \
			"Joe.\r\n"

#define KEY		"-----BEGIN RSA PRIVATE KEY-----\n" \
	"MIICXQIBAAKBgQC4GUGr+d/6SFNzVLYpphnRd0QPGKz2uWnV65RAxa1Pw352Bqiz\n" \
	"qiKOBjgYGzj8pJQSs8tOvv/2k6jpI809RnESqOFgF0gu3UJbNnu3+cd8k/kiQj+q\n" \
	"4cKKRpAT92ccxc7svhCNgN1sBGmROYZuysG3Vu3Dyc079gSLtnSrgXb+gQIDAQAB\n" \
	"AoGAemlI0opm1Kvs2T4VliH8/tvX5FXbBH8LEZQAUwVeFTB/UQlieXyCV39pIxZO\n" \
	"0Sa50qm8YNL9rb5HTSZiHQFOwyAKNqS4m/7JCsbuH4gQkPgPF561BHNL9oKfYgJq\n" \
	"9P4kEFfDTBoXKBMxwWtT7AKV8dYvCa3vYzPQ/1BnqQdw2zECQQDyscdgR9Ih59PQ\n" \
	"b72ddibdsxS65uXS2vzYLe7SKl+4R5JgJzw0M6DTAnoYFf6JAsKGZM15PCC0E16t\n" \
	"RRo47U9VAkEAwjEVrlQ0/8yPACbDggDJg/Zz/uRu1wK0zjqj4vKjleubaX4SEvj7\n" \
	"r6xxZm9hC1pMJAC9y3bbkbgCRBjXfyY6fQJBANe5aq2MaZ41wTOPf45NjbKXEiAo\n" \
	"SbUpboKCIbyyaa8V/2h0t7D3C0dE9l4efsguqdZoF7Rh2/f1F70QpYRgfJkCQQCH\n" \
	"oRrAeGXP50JVW72fNgeJGH/pnghgOa6of0JpxwhENJuGMZxUDfxTtUA6yD3iXP3j\n" \
	"A3WL/wbaHsfOYf9Y+g1NAkAGLhx67Ah+uBNK4Xvfz0YPGINX20m+CMsxAw7FOaNv\n" \
	"IW2oWFfZCB4APkIis79Ql45AHpavwx5XodBMzZwJUvlL\n" \
	"-----END RSA PRIVATE KEY-----\n"
#define	PUBLICKEY	"v=DKIM1; k=rsa; t=y; p=" \
	"MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC4GUGr+d/6SFNzVLYpphnRd0QP" \
	"GKz2uWnV65RAxa1Pw352BqizqiKOBjgYGzj8pJQSs8tOvv/2k6jpI809RnESqOFg" \
	"F0gu3UJbNnu3+cd8k/kiQj+q4cKKRpAT92ccxc7svhCNgN1sBGmROYZuysG3Vu3D" \
	"yc079gSLtnSrgXb+gQIDAQAB"
#define	PUBLICKEY2	"v=DKIM1; p=MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQ" \
	"KBgQDwIRP/UC3SBsEmGqZ9ZJW3/DkMoGeLnQg1fWn7/zYt" \
	"IxN2SnFCjxOCKG9v3b4jYfcTNh5ijSsq631uBItLa7od+v" \
	"/RtdC2UzJ1lWT947qR+Rcac2gbto/NMqJ0fzfVjH4OuKhi" \
	"tdY9tf6mcwGjaNBcWToIMmPSPDdQPNUYckcQ2QIDAQAB"

#define	GIBBERISH	"abcdefghijklmnopqrstuvwxyz ABCDEFGHIJKLMNOPQRSTUVWXYZ 0123456789 !@#$%^&*()_+|-={}[];':,./<>?`~\r\n"

#define	CRLF		"\r\n"

#define	LARGEBODYSIZE	65536

#define	KEYFILE		"/var/tmp/testkeys"

#define	JOBID		"testing"
#define	SELECTOR	"test"
#define	SELECTOR2	"brisbane"
#define	DOMAIN		"example.com"
